import React from 'react';
import ShallowRenderer from 'react-test-renderer/shallow';

import ButtonControls from '.';

const renderer = new ShallowRenderer();

describe('ButtonControls component', () => {
  let buttonProps;

  beforeEach(() => {
    buttonProps = {
      buttons: [
        {
          label: 'Message',
          buttonType: 'chat'
        },
        {
          label: 'Call',
          buttonType: 'camera'
        }
      ]
    };
  });

  it('renders properly with labels', () => {
    buttonProps.showLabels = true;
    renderer.render(<ButtonControls {...buttonProps} />);
    const component = renderer.getRenderOutput();

    expect(component).toMatchSnapshot();
  });

  it('renders properly without labels', () => {
    buttonProps.showLabels = false;
    renderer.render(<ButtonControls {...buttonProps} />);
    const component = renderer.getRenderOutput();

    expect(component).toMatchSnapshot();
  });

  describe('when it has accessibility labels', () => {
    beforeEach(() => {
      buttonProps.buttons = buttonProps.buttons.map((button) => {
        const b = button;

        b.accessibilityLabel = 'accessibilityLabel';

        return b;
      });
    });

    it('renders properly with labels', () => {
      buttonProps.showLabels = true;
      renderer.render(<ButtonControls {...buttonProps} />);
      const component = renderer.getRenderOutput();

      expect(component).toMatchSnapshot();
    });

    it('renders properly without labels', () => {
      buttonProps.showLabels = false;
      renderer.render(<ButtonControls {...buttonProps} />);
      const component = renderer.getRenderOutput();

      expect(component).toMatchSnapshot();
    });
  });
});
